=============
API reference
=============

This page gives an overview of all public snapatac2 objects, functions and
methods.

.. toctree::
   :maxdepth: 2

   io
   preprocessing
   tools
   metrics
   plotting
   export
   motif
   datasets
   recipes